0.4.0
=====

mosviz is no longer supported, please use jdaviz. If you must use legacy
mosviz, please try v0.3.1 in Python 3.6.

0.3.0
=====

New Features
------------

- Integrated latest version of ``specviz``

- Updated loaders for JWST data products

- Added cutout tool functionality

- UI improvements

Bug Fixes
---------

- Minor bug fixes


0.2.1 (2019-12-15)
==================

Current release, place holder.
